==> library1.4.1.tar.bz2: library/utils/bottom.php <==
                     </td>
                    </tr>
                    <tr>
                      <td>
                      <hr size="3" width="98%" />
                        <table width="100%"  border="0" cellspacing="0" cellpadding="0">
                          <tr>
                            <td class="menu" align="left" width="70%">
                            <?php
                            $query_b1 = mysqli_query($dbcnx,"SELECT COUNT(book_id) AS cbid1 FROM tbl_book WHERE (vidano!='2' AND vidano!='3')");
	                     $coun_b = mysqli_fetch_array($query_b1);
		              $query_b_out = mysqli_query($dbcnx,"SELECT COUNT(book_id) AS cbid2 FROM tbl_book WHERE visible='1' AND vidano='1'");
		               $coun_b_out = mysqli_fetch_array($query_b_out);
                                $query_b_zak = mysqli_query($dbcnx,"SELECT COUNT(book_id) AS cbid3 FROM tbl_book WHERE visible='1' AND zakazano='1'");
		                 $coun_b_zak = mysqli_fetch_array($query_b_zak);
	                            echo "".$TEXT['global-now']."<b> ".$coun_b['cbid1']."</b>";
                            ?>
                            </td>
                            <?php
                            if (is_file ("lang/".$lang."/docs/index.html")) {echo "<td rowspan=2 align='right' width='30%'><a href='lang/".$lang."/docs/index.html' class='img' target=_blank title='". $TEXT['global-documents']."' ><img alt='picture' src= 'skins/".$result2['skin']."/help.png' ></a></td>";}
                              else {echo "<td rowspan=2 align='right' width='30%'><a href='lang/ru/docs/index.html' class='img' target=_blank title='". $TEXT['global-documents']."' ><img alt='picture' src= 'skins/".$result2['skin']."/help.png' ></a></td>";}
                          ?>
                          </tr>
                          <tr>
                          <td class="menu"><?php echo $TEXT['global-out-book']; ?><b><?php echo $coun_b_out['cbid2']; ?> / <?php echo $coun_b_zak['cbid3']; ?></b></td>
                          <td></td>
                          </tr>
                          <tr>
                          <td class="menu">&nbsp;</td>
                          <td class="menu" align="right"><a href=# onClick="window.open('about.php','popup','top=<?php echo $TEXT['user-top']; ?>,left=<?php echo $TEXT['user-left']; ?>,width=<?php echo $TEXT['about-width']; ?>,height=<?php echo $TEXT['about-height']; ?>,status=no,scrollbars=no,location=no,menubar=no,toolbar=no')" title="<?php echo $TEXT['menu-btn8-title']; ?>"><span class="menu"><?php echo $TEXT['global-title']; ?>, <?php echo $TEXT['maker8']; ?></span></a></td>
                          </tr>
                        </table>
                      </td>
                    </tr>
                  </table>
                    </td>
                  <td class="osn_right">&nbsp;</td>
                </tr>
                <tr>
                  <td class="osn_bottom_r"></td>
                  <td class="osn_bottom"></td>
                  <td class="osn_bottom_l"></td>
                </tr>
              </table>
           </body>
           </html>

==> library1.19.1.tar.bz2: library/utils/bottom.php <==
                     </td>
                    </tr>
                    <tr>
                      <td>
                      <hr size="3" width="98%" />
                        <table width="100%"  border="0" cellspacing="0" cellpadding="0">
                          <tr>
                            <td class="menu" align="left" width="70%">
                            <?php
                            $query_b1 = mysqli_query($dbcnx,"SELECT COUNT(book_id) AS cbid1 FROM tbl_book WHERE (vidano!='2' AND vidano!='3')");
	                     $coun_b = mysqli_fetch_array($query_b1);
		              $query_b_out = mysqli_query($dbcnx,"SELECT COUNT(book_id) AS cbid2 FROM tbl_book WHERE visible='1' AND vidano='1'");
		               $coun_b_out = mysqli_fetch_array($query_b_out);
                                $query_b_zak = mysqli_query($dbcnx,"SELECT COUNT(book_id) AS cbid3 FROM tbl_book WHERE visible='1' AND zakazano='1'");
		                 $coun_b_zak = mysqli_fetch_array($query_b_zak);
	                            echo "".$TEXT['global-now']."<b> ".$coun_b['cbid1']."</b>";
                            ?>
                            </td>
                            <?php
                            // Maintenance mode (show preduprezdenie)
                            if($result2_m['maint_run'] > 0 && $result2['administrator'] == 1)
                             {
                              echo "<td rowspan=2 align='right'><div id='formaupdate3'>".$TEXT['global-maintenance-info']."<img alt='picture' src= 'skins/".$result2['skin']."/pass16.png' ></div></td>";
                             }
                                else 
                                {
                                 // вывод ссылки на справку
                                 if(is_file ("lang/".$lang."/docs/index.html")) {echo "<td rowspan=2 align='right' width='30%'><a href='lang/".$lang."/docs/index.html' class='img' target=_blank title='". $TEXT['global-documents']."' ><img alt='picture' src= 'skins/".$result2['skin']."/help.png' ></a></td>";}
                                   else {echo "<td rowspan=2 align='right' width='30%'><a href='lang/ru/docs/index.html' class='img' target=_blank title='". $TEXT['global-documents']."' ><img alt='picture' src= 'skins/".$result2['skin']."/help.png' ></a></td>";}
                                }
                          ?>
                          </tr>
                          <tr>
                          <td class="menu"><?php echo $TEXT['global-out-book']; ?><b><?php echo $coun_b_out['cbid2']; ?> / <?php echo $coun_b_zak['cbid3']; ?></b></td>
                          <td></td>
                          </tr>
                          <tr>
                          <td class="menu">&nbsp;

                          </td>
                          <td class="menu" align="right"><a href=# onClick="window.open('about.php','popup','top=<?php echo $TEXT['user-top']; ?>,left=<?php echo $TEXT['user-left']; ?>,width=<?php echo $TEXT['about-width']; ?>,height=<?php echo $TEXT['about-height']; ?>,status=no,scrollbars=no,location=no,menubar=no,toolbar=no')" title="<?php echo $TEXT['menu-btn8-title']; ?>"><span class="menu"><?php echo $TEXT['global-title']; ?>, <?php echo $TEXT['maker8']; ?></span></a></td>
                          </tr>
                        </table>
                      </td>
                    </tr>
                  </table>
                    </td>
                  <td class="osn_right">&nbsp;</td>
                </tr>
                <tr>
                  <td class="osn_bottom_r"></td>
                  <td class="osn_bottom"></td>
                  <td class="osn_bottom_l"></td>
                </tr>
              </table>
           </body>
           </html>
